YUI.add("moodle-core-event",function(e,o){var n,t,r,c;if(M.core=M.core||{},n=!!M.core.event,M.core.event=M.core.event||{FILTER_CONTENT_UPDATED:"filter-content-updated",EDITOR_CONTENT_RESTORED:"editor-content-restored",FORM_SUBMIT_AJAX:"form-submit-ajax"},M.core.globalEvents=M.core.globalEvents||{FORM_ERROR:"form_error",BLOCK_CONTENT_UPDATED:"block_content_updated"},!n){for(r in t={emitFacade:!0,defaultFn:function(e){},preventedFn:function(e){},stoppedFn:function(e){}},M.core.event)M.core.event.hasOwnProperty(r)&&null===e.getEvent(M.core.event[r])&&e.publish(M.core.event[r],t);for(r in M.core.globalEvents)M.core.globalEvents.hasOwnProperty(r)&&null===e.Global.getEvent(M.core.globalEvents[r])&&e.Global.publish(M.core.globalEvents[r],e.merge(t,{broadcast:!0}));c=function(o,n){new MutationObserver(function(e){e.forEach(function(e){e.addedNodes.forEach(function(e){e instanceof Element&&e.matches(o)&&n(e)})})}).observe(document,{childList:!0,subtree:!0})},require(["core_form/events"],function(n){c("form",function(o){e.one(o).on(M.core.event.FORM_SUBMIT_AJAX,function(e){e&&e.fallbackHandled||n.notifyFormSubmittedByJavascript(o,window.skipValidation,!0)})})})}},"@VERSION@",{requires:["event-custom"]});